%define lib_major	1
%define lib_name	%mklibname %name %{lib_major}
%define develname	%mklibname %{name} -d

# virtual package to enforce naming convention

Summary:	The UCL Compression Library
Name:		ucl
Version:	1.03
Release:	%mkrel 20
License:	GPLv2+
Group:		System/Libraries
URL:		https://www.oberhumer.com/opensource/ucl/
Source0:	https://www.oberhumer.com/opensource/ucl/download/%name-%version.tar.bz2
# From Debian:
Patch101:	01-Examples.patch
Patch102:	02-Autoreconf.patch
Patch103:	03-Reproducible-build.patch
Patch104:	04-Static-assert.patch
# From OpenSuSE:
Patch105:	upx-207.patch

BuildRequires:	libtool

%description
UCL implements a number of algorithms with the following features:
- Decompression is simple and *very* fast.
- Requires no memory for decompression.
- The decompressors can be squeezed into less than 200 bytes of code.
- Focuses on compression levels for generating pre-compressed data which
  achieve a quite competitive compression ratio.
- Allows you to dial up extra compression at a speed cost in the compressor.
  The speed of the decompressor is not reduced.
- Algorithm is thread safe.
- Algorithm is lossless.
UCL supports in-place decompression.


# main package (contains *.so.[major].* only)

%package -n	%{lib_name}
Summary:	The UCL Compression Library
Group:		System/Libraries
Provides:	%{name} = %{version}-%{release}

%description -n	%{lib_name}
UCL implements a number of algorithms with the following features:
- Decompression is simple and *very* fast.
- Requires no memory for decompression.
- The decompressors can be squeezed into less than 200 bytes of code.
- Focuses on compression levels for generating pre-compressed data which
  achieve a quite competitive compression ratio.
- Allows you to dial up extra compression at a speed cost in the compressor.
  The speed of the decompressor is not reduced.
- Algorithm is thread safe.
- Algorithm is lossless.
UCL supports in-place decompression.

This package contains the library needed to run programs dynamically
linked with %{lib_name_orig}.


# devel part of the bundle

%package -n	%{develname}
Summary:	The UCL Compression Library - development environment
Group:		Development/C
Requires:	%{lib_name} = %{version}-%release
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
UCL implements a number of algorithms with the following features:
- Decompression is simple and *very* fast.
- Requires no memory for decompression.
- The decompressors can be squeezed into less than 200 bytes of code.
- Focuses on compression levels for generating pre-compressed data which
  achieve a quite competitive compression ratio.
- Allows you to dial up extra compression at a speed cost in the compressor.
  The speed of the decompressor is not reduced.
- Algorithm is thread safe.
- Algorithm is lossless.
UCL supports in-place decompression.

Install %{name} if you need to compile an application with %{lib_name}
support.

%prep
%setup -q
%autopatch -p1

%build
# fix build on aarch64
autoreconf -vfi

export CPPFLAGS="%{optflags} -fPIC"
%configure --enable-shared --disable-static
%make_build

%install
%make_install

find %{buildroot} -name '*.la' -delete

%files -n %{lib_name}
%doc COPYING NEWS README THANKS TODO
%{_libdir}/*.so.%{lib_major}
%{_libdir}/*.so.%{lib_major}.*

%files  -n %{develname}
%doc COPYING NEWS README THANKS TODO
%{_libdir}/*.so
%{_includedir}/ucl


%changelog
* Thu Jun 26 2025 umeabot <umeabot> 1.03-20.mga10
+ Revision: 2195949
- Mageia 10 Mass Rebuild

* Wed Mar 16 2022 umeabot <umeabot> 1.03-19.mga9
+ Revision: 1794550
- Mageia 9 Mass Rebuild

* Fri Feb 21 2020 ns80 <ns80> 1.03-18.mga8
+ Revision: 1549208
- add patch from OpenSuSE for CVE-2018-11243 (mga#26172)

* Fri Feb 14 2020 umeabot <umeabot> 1.03-17.mga8
+ Revision: 1517637
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 1.03-16.mga7
+ Revision: 1301489
- Mageia 7 Mass Rebuild

* Mon Jul 30 2018 wally <wally> 1.03-15.mga7
+ Revision: 1246120
- add patches from Debian

* Wed Oct 11 2017 daviddavid <daviddavid> 1.03-14.mga7
+ Revision: 1170848
- compile with '-std=c90 -fPIC' CPPFLAGS flags

* Thu Feb 04 2016 umeabot <umeabot> 1.03-13.mga6
+ Revision: 935934
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.03-12.mga5
+ Revision: 742119
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.03-11.mga5
+ Revision: 690010
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.03-10.mga4
+ Revision: 519834
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 1.03-9.mga3
+ Revision: 384942
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Oct 13 2012 fwang <fwang> 1.03-8.mga3
+ Revision: 305180
- drop .la file
- fix typo
- drop .la file
- new devel package policy

* Thu Jan 20 2011 erwan <erwan> 1.03-7.mga1
+ Revision: 27480
- Fixing macro
- imported package ucl


* Wed Sep 09 2009 Thierry Vignaud <tvignaud@mandriva.com> 1.03-7mdv2010.0
+ Revision: 434493
- rebuild
- rebuild

* Wed Jul 30 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.03-5mdv2009.0
+ Revision: 255037
- rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Wed Jan 02 2008 Olivier Blin <oblin@mandriva.com> 1.03-3mdv2008.1
+ Revision: 140924
- restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request


* Mon Dec 11 2006 Oden Eriksson <oeriksson@mandriva.com> 1.03-3mdv2007.0
+ Revision: 94911
- rebuild
- Import ucl

* Mon Dec 11 2006 Oden Eriksson <oeriksson@mandriva.com> 1.03-2mdv2007.1
- rebuild

* Sun Oct 03 2004 Goetz Waschk <waschk@linux-mandrake.com> 1.03-1mdk
- New release 1.03

* Thu Jul 01 2004 Götz Waschk <waschk@linux-mandrake.com> 1.02-1mdk
- major 1
- source URL
- New release 1.02

